#
# spec file for package Botan
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define version_suffix 1_10-1
%define short_version 1.10
Name:           Botan
Version:        1.10.17
Release:        0
Summary:        A C++ Crypto Library
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Url:            http://botan.randombit.net
Source0:        http://botan.randombit.net/releases/%{name}-%{version}.tgz
Source1:        http://botan.randombit.net/releases/%{name}-%{version}.tgz.asc
Source2:        %{name}.keyring
Source3:        baselibs.conf
Patch0:         Botan-inttypes.patch
Patch1:         Botan-ull_constants.patch.bz2
Patch2:         Botan-fix_install_paths.patch
Patch4:         Botan-no-buildtime.patch
Patch6:         Botan-fix_pkgconfig.patch
Patch7:         dont-set-mach-value.diff
Patch8:         aarch64-support.patch
Patch10:        no-cpuid-header.patch
BuildRequires:  bzip2 >= 1.0.2
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel >= 4.1
BuildRequires:  libbz2-devel
# Botan 1.x doesn't build with OpenSSL 1.1, so explicitly require OpenSSL 1.0.x
%if %{suse_version} < 1330
BuildRequires:  openssl-devel
%else
BuildRequires:  libopenssl-1_0_0-devel
%endif
BuildRequires:  pkg-config
BuildRequires:  python
BuildRequires:  zlib-devel
Requires:       bzip2 >= 1.0.2
Requires:       gmp >= 4.1
Requires:       zlib
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Botan is a C++ library that provides support for many common
cryptographic operations, including encryption, authentication, and
X.509v3 certificates and CRLs. A wide variety of algorithms is
supported, including RSA, DSA, DES, AES, MD5, and SHA-1.

%package  -n    libbotan-%{version_suffix}
Summary:        A C++ Crypto Library
Group:          Development/Libraries/C and C++

%description -n libbotan-%{version_suffix}
Botan is a C++ library that provides support for many common
cryptographic operations, including encryption, authentication, and
X.509v3 certificates and CRLs. A wide variety of algorithms is
supported, including RSA, DSA, DES, AES, MD5, and SHA-1.

%package        -n libbotan-devel
%define botan_docdir %{_docdir}/%{name}-%{version}
Summary:        Development files for Botan
Group:          Development/Libraries/C and C++
Requires:       gmp-devel >= 4.1
Requires:       libbotan-%{version_suffix} = %{version}
Requires:       libbz2-devel
Provides:       Botan-devel = %{version}
Obsoletes:      Botan-devel < %{version}

%description    -n libbotan-devel
This package contains the header files and libraries needed to develop
programs that use the Botan library.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch4
%patch6
%patch7 -p1
%patch8 -p1
%if 0%{?suse_version} == 1110
%patch10 -p1
%endif

%build
export RPM_OPT_FLAGS

./configure.py \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --docdir=%{_defaultdocdir} \
  --includedir=%{_includedir} \
  --with-bzip2 \
  --with-zlib \
  --with-gnump \
  --with-openssl \
  --with-tr1-implementation=system  \
  --cpu=%{_target_cpu}
make %{?_smp_mflags} WARN_FLAGS="%{optflags}"

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm -f %{buildroot}/%{_libdir}/libbotan*.a

%post -n libbotan-%{version_suffix} -p /sbin/ldconfig

%postun -n libbotan-%{version_suffix} -p /sbin/ldconfig

%files -n libbotan-%{version_suffix}
%defattr(-,root,root)
%docdir %{botan_docdir}
%{botan_docdir}
%{_libdir}/libbotan-%{short_version}.so.*

%files -n libbotan-devel
%defattr(-,root,root)
%{_libdir}/libbotan-%{short_version}.so
%{_libdir}/pkgconfig/botan-%{short_version}.pc
%{_includedir}/botan-%{short_version}
%{_bindir}/botan-config-%{short_version}

%changelog
